@@ -116,9 +116,13 @@ nls_fit = function(data, dose = 100,
       )
     )
   }
-  cf = purrr::map_df(pars, rbind )  %>% 
-    filter(value != 0) %>% 
-    tibble::as_tibble(cf)
+  cf = purrr::map_df(pars, rbind )  
+  cf = cf %>% filter(value != 0) 
+  # Gives warning  with testthat 3.0
+  # The `validate` argument of `as_tibble()` is deprecated as of tibble 2.0.0.
+  # Please use the `.name_repair` argument instead.
+  cf = cf %>% 
+    tibble::as_tibble(cf, .name_repair = "minimal")
   
   ret = list(coef = cf, data = data, nls_fit = bid.nls)
   class(ret) = c("breathtestnlsfit", "breathtestfit" )
